# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/route/v4alpha/scoped_route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/route/v4alpha/scoped_route.proto',
  package='envoy.config.route.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.config.route.v4alphaB\020ScopedRouteProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-envoy/config/route/v4alpha/scoped_route.proto\x12\x1a\x65nvoy.config.route.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8d\x04\n\x18ScopedRouteConfiguration\x12\x11\n\ton_demand\x18\x04 \x01(\x08\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12)\n\x18route_configuration_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12O\n\x03key\x18\x03 \x01(\x0b\x32\x38.envoy.config.route.v4alpha.ScopedRouteConfiguration.KeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\x93\x02\n\x03Key\x12^\n\tfragments\x18\x01 \x03(\x0b\x32\x41.envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.FragmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aq\n\x08\x46ragment\x12\x14\n\nstring_key\x18\x01 \x01(\tH\x00:B\x9a\xc5\x88\x1e=\n;envoy.config.route.v3.ScopedRouteConfiguration.Key.FragmentB\x0b\n\x04type\x12\x03\xf8\x42\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.config.route.v3.ScopedRouteConfiguration.Key:5\x9a\xc5\x88\x1e\x30\n.envoy.config.route.v3.ScopedRouteConfigurationBF\n(io.envoyproxy.envoy.config.route.v4alphaB\x10ScopedRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT = _descriptor.Descriptor(
  name='Fragment',
  full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.Fragment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_key', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.Fragment.string_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.route.v3.ScopedRouteConfiguration.Key.Fragment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.Fragment.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=467,
  serialized_end=580,
)

_SCOPEDROUTECONFIGURATION_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fragments', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.fragments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.route.v3.ScopedRouteConfiguration.Key',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=639,
)

_SCOPEDROUTECONFIGURATION = _descriptor.Descriptor(
  name='ScopedRouteConfiguration',
  full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='on_demand', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.on_demand', index=0,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_configuration_name', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.route_configuration_name', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.route.v4alpha.ScopedRouteConfiguration.key', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTECONFIGURATION_KEY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.route.v3.ScopedRouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=694,
)

_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.containing_type = _SCOPEDROUTECONFIGURATION_KEY
_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type'].fields.append(
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.fields_by_name['string_key'])
_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.fields_by_name['string_key'].containing_oneof = _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']
_SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments'].message_type = _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT
_SCOPEDROUTECONFIGURATION_KEY.containing_type = _SCOPEDROUTECONFIGURATION
_SCOPEDROUTECONFIGURATION.fields_by_name['key'].message_type = _SCOPEDROUTECONFIGURATION_KEY
DESCRIPTOR.message_types_by_name['ScopedRouteConfiguration'] = _SCOPEDROUTECONFIGURATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScopedRouteConfiguration = _reflection.GeneratedProtocolMessageType('ScopedRouteConfiguration', (_message.Message,), {

  'Key' : _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {

    'Fragment' : _reflection.GeneratedProtocolMessageType('Fragment', (_message.Message,), {
      'DESCRIPTOR' : _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT,
      '__module__' : 'envoy.config.route.v4alpha.scoped_route_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.ScopedRouteConfiguration.Key.Fragment)
      })
    ,
    'DESCRIPTOR' : _SCOPEDROUTECONFIGURATION_KEY,
    '__module__' : 'envoy.config.route.v4alpha.scoped_route_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.ScopedRouteConfiguration.Key)
    })
  ,
  'DESCRIPTOR' : _SCOPEDROUTECONFIGURATION,
  '__module__' : 'envoy.config.route.v4alpha.scoped_route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.ScopedRouteConfiguration)
  })
_sym_db.RegisterMessage(ScopedRouteConfiguration)
_sym_db.RegisterMessage(ScopedRouteConfiguration.Key)
_sym_db.RegisterMessage(ScopedRouteConfiguration.Key.Fragment)


DESCRIPTOR._options = None
_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']._options = None
_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT._options = None
_SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments']._options = None
_SCOPEDROUTECONFIGURATION_KEY._options = None
_SCOPEDROUTECONFIGURATION.fields_by_name['name']._options = None
_SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration_name']._options = None
_SCOPEDROUTECONFIGURATION.fields_by_name['key']._options = None
_SCOPEDROUTECONFIGURATION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/squash/v3/squash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/squash/v3/squash.proto',
  package='envoy.extensions.filters.http.squash.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.squash.v3B\013SquashProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/squash/v3/squash.proto\x12\'envoy.extensions.filters.http.squash.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x06Squash\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x13\x61ttachment_template\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x0frequest_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12\x61ttachment_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x16\x61ttachment_poll_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.squash.v2.SquashBN\n5io.envoyproxy.envoy.extensions.filters.http.squash.v3B\x0bSquashProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SQUASH = _descriptor.Descriptor(
  name='Squash',
  full_name='envoy.extensions.filters.http.squash.v3.Squash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.http.squash.v3.Squash.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_template', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.extensions.filters.http.squash.v3.Squash.request_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_timeout', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_timeout', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_poll_period', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_poll_period', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.squash.v2.Squash',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=555,
)

_SQUASH.fields_by_name['attachment_template'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SQUASH.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SQUASH.fields_by_name['attachment_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SQUASH.fields_by_name['attachment_poll_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Squash'] = _SQUASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Squash = _reflection.GeneratedProtocolMessageType('Squash', (_message.Message,), {
  'DESCRIPTOR' : _SQUASH,
  '__module__' : 'envoy.extensions.filters.http.squash.v3.squash_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.squash.v3.Squash)
  })
_sym_db.RegisterMessage(Squash)


DESCRIPTOR._options = None
_SQUASH.fields_by_name['cluster']._options = None
_SQUASH._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/fault/v2/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/fault/v2/fault.proto',
  package='envoy.config.filter.fault.v2',
  syntax='proto3',
  serialized_options=b'\n*io.envoyproxy.envoy.config.filter.fault.v2B\nFaultProtoP\001\362\230\376\217\005*\022(envoy.extensions.filters.common.fault.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/config/filter/fault/v2/fault.proto\x12\x1c\x65nvoy.config.filter.fault.v2\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe9\x02\n\nFaultDelay\x12O\n\x04type\x18\x01 \x01(\x0e\x32\x37.envoy.config.filter.fault.v2.FaultDelay.FaultDelayTypeB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12:\n\x0b\x66ixed_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12L\n\x0cheader_delay\x18\x05 \x01(\x0b\x32\x34.envoy.config.filter.fault.v2.FaultDelay.HeaderDelayH\x00\x12\x31\n\npercentage\x18\x04 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x1a\r\n\x0bHeaderDelay\"\x1b\n\x0e\x46\x61ultDelayType\x12\t\n\x05\x46IXED\x10\x00\x42\x1b\n\x14\x66\x61ult_delay_secifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03\"\xb2\x02\n\x0e\x46\x61ultRateLimit\x12N\n\x0b\x66ixed_limit\x18\x01 \x01(\x0b\x32\x37.envoy.config.filter.fault.v2.FaultRateLimit.FixedLimitH\x00\x12P\n\x0cheader_limit\x18\x03 \x01(\x0b\x32\x38.envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimitH\x00\x12\x31\n\npercentage\x18\x02 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x1a)\n\nFixedLimit\x12\x1b\n\nlimit_kbps\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x1a\r\n\x0bHeaderLimitB\x11\n\nlimit_type\x12\x03\xf8\x42\x01\x42r\n*io.envoyproxy.envoy.config.filter.fault.v2B\nFaultProtoP\x01\xf2\x98\xfe\x8f\x05*\x12(envoy.extensions.filters.common.fault.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_FAULTDELAY_FAULTDELAYTYPE = _descriptor.EnumDescriptor(
  name='FaultDelayType',
  full_name='envoy.config.filter.fault.v2.FaultDelay.FaultDelayType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=557,
  serialized_end=584,
)
_sym_db.RegisterEnumDescriptor(_FAULTDELAY_FAULTDELAYTYPE)


_FAULTDELAY_HEADERDELAY = _descriptor.Descriptor(
  name='HeaderDelay',
  full_name='envoy.config.filter.fault.v2.FaultDelay.HeaderDelay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=555,
)

_FAULTDELAY = _descriptor.Descriptor(
  name='FaultDelay',
  full_name='envoy.config.filter.fault.v2.FaultDelay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.config.filter.fault.v2.FaultDelay.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_delay', full_name='envoy.config.filter.fault.v2.FaultDelay.fixed_delay', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_delay', full_name='envoy.config.filter.fault.v2.FaultDelay.header_delay', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='envoy.config.filter.fault.v2.FaultDelay.percentage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FAULTDELAY_HEADERDELAY, ],
  enum_types=[
    _FAULTDELAY_FAULTDELAYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='fault_delay_secifier', full_name='envoy.config.filter.fault.v2.FaultDelay.fault_delay_secifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=258,
  serialized_end=619,
)


_FAULTRATELIMIT_FIXEDLIMIT = _descriptor.Descriptor(
  name='FixedLimit',
  full_name='envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit_kbps', full_name='envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit.limit_kbps', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0042\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=894,
)

_FAULTRATELIMIT_HEADERLIMIT = _descriptor.Descriptor(
  name='HeaderLimit',
  full_name='envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=909,
)

_FAULTRATELIMIT = _descriptor.Descriptor(
  name='FaultRateLimit',
  full_name='envoy.config.filter.fault.v2.FaultRateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixed_limit', full_name='envoy.config.filter.fault.v2.FaultRateLimit.fixed_limit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_limit', full_name='envoy.config.filter.fault.v2.FaultRateLimit.header_limit', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='envoy.config.filter.fault.v2.FaultRateLimit.percentage', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FAULTRATELIMIT_FIXEDLIMIT, _FAULTRATELIMIT_HEADERLIMIT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='limit_type', full_name='envoy.config.filter.fault.v2.FaultRateLimit.limit_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=622,
  serialized_end=928,
)

_FAULTDELAY_HEADERDELAY.containing_type = _FAULTDELAY
_FAULTDELAY.fields_by_name['type'].enum_type = _FAULTDELAY_FAULTDELAYTYPE
_FAULTDELAY.fields_by_name['fixed_delay'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FAULTDELAY.fields_by_name['header_delay'].message_type = _FAULTDELAY_HEADERDELAY
_FAULTDELAY.fields_by_name['percentage'].message_type = envoy_dot_type_dot_percent__pb2._FRACTIONALPERCENT
_FAULTDELAY_FAULTDELAYTYPE.containing_type = _FAULTDELAY
_FAULTDELAY.oneofs_by_name['fault_delay_secifier'].fields.append(
  _FAULTDELAY.fields_by_name['fixed_delay'])
_FAULTDELAY.fields_by_name['fixed_delay'].containing_oneof = _FAULTDELAY.oneofs_by_name['fault_delay_secifier']
_FAULTDELAY.oneofs_by_name['fault_delay_secifier'].fields.append(
  _FAULTDELAY.fields_by_name['header_delay'])
_FAULTDELAY.fields_by_name['header_delay'].containing_oneof = _FAULTDELAY.oneofs_by_name['fault_delay_secifier']
_FAULTRATELIMIT_FIXEDLIMIT.containing_type = _FAULTRATELIMIT
_FAULTRATELIMIT_HEADERLIMIT.containing_type = _FAULTRATELIMIT
_FAULTRATELIMIT.fields_by_name['fixed_limit'].message_type = _FAULTRATELIMIT_FIXEDLIMIT
_FAULTRATELIMIT.fields_by_name['header_limit'].message_type = _FAULTRATELIMIT_HEADERLIMIT
_FAULTRATELIMIT.fields_by_name['percentage'].message_type = envoy_dot_type_dot_percent__pb2._FRACTIONALPERCENT
_FAULTRATELIMIT.oneofs_by_name['limit_type'].fields.append(
  _FAULTRATELIMIT.fields_by_name['fixed_limit'])
_FAULTRATELIMIT.fields_by_name['fixed_limit'].containing_oneof = _FAULTRATELIMIT.oneofs_by_name['limit_type']
_FAULTRATELIMIT.oneofs_by_name['limit_type'].fields.append(
  _FAULTRATELIMIT.fields_by_name['header_limit'])
_FAULTRATELIMIT.fields_by_name['header_limit'].containing_oneof = _FAULTRATELIMIT.oneofs_by_name['limit_type']
DESCRIPTOR.message_types_by_name['FaultDelay'] = _FAULTDELAY
DESCRIPTOR.message_types_by_name['FaultRateLimit'] = _FAULTRATELIMIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaultDelay = _reflection.GeneratedProtocolMessageType('FaultDelay', (_message.Message,), {

  'HeaderDelay' : _reflection.GeneratedProtocolMessageType('HeaderDelay', (_message.Message,), {
    'DESCRIPTOR' : _FAULTDELAY_HEADERDELAY,
    '__module__' : 'envoy.config.filter.fault.v2.fault_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.fault.v2.FaultDelay.HeaderDelay)
    })
  ,
  'DESCRIPTOR' : _FAULTDELAY,
  '__module__' : 'envoy.config.filter.fault.v2.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.fault.v2.FaultDelay)
  })
_sym_db.RegisterMessage(FaultDelay)
_sym_db.RegisterMessage(FaultDelay.HeaderDelay)

FaultRateLimit = _reflection.GeneratedProtocolMessageType('FaultRateLimit', (_message.Message,), {

  'FixedLimit' : _reflection.GeneratedProtocolMessageType('FixedLimit', (_message.Message,), {
    'DESCRIPTOR' : _FAULTRATELIMIT_FIXEDLIMIT,
    '__module__' : 'envoy.config.filter.fault.v2.fault_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit)
    })
  ,

  'HeaderLimit' : _reflection.GeneratedProtocolMessageType('HeaderLimit', (_message.Message,), {
    'DESCRIPTOR' : _FAULTRATELIMIT_HEADERLIMIT,
    '__module__' : 'envoy.config.filter.fault.v2.fault_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit)
    })
  ,
  'DESCRIPTOR' : _FAULTRATELIMIT,
  '__module__' : 'envoy.config.filter.fault.v2.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.fault.v2.FaultRateLimit)
  })
_sym_db.RegisterMessage(FaultRateLimit)
_sym_db.RegisterMessage(FaultRateLimit.FixedLimit)
_sym_db.RegisterMessage(FaultRateLimit.HeaderLimit)


DESCRIPTOR._options = None
_FAULTDELAY.oneofs_by_name['fault_delay_secifier']._options = None
_FAULTDELAY.fields_by_name['type']._options = None
_FAULTDELAY.fields_by_name['fixed_delay']._options = None
_FAULTRATELIMIT_FIXEDLIMIT.fields_by_name['limit_kbps']._options = None
_FAULTRATELIMIT.oneofs_by_name['limit_type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.thrift_proxy.v3 import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto',
  package='envoy.extensions.filters.network.thrift_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\020ThriftProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x03\n\x0bThriftProxy\x12\\\n\ttransport\x18\x02 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x03 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12Z\n\x0croute_config\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.filters.network.thrift_proxy.v3.RouteConfiguration\x12V\n\x0ethrift_filters\x18\x05 \x03(\x0b\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter\x12\x1b\n\x13payload_passthrough\x18\x06 \x01(\x08:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy\"\xb7\x01\n\x0cThriftFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:E\x9a\xc5\x88\x1e@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xa1\x02\n\x15ThriftProtocolOptions\x12\\\n\ttransport\x18\x01 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x02 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:N\x9a\xc5\x88\x1eI\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions*I\n\rTransportType\x12\x12\n\x0e\x41UTO_TRANSPORT\x10\x00\x12\n\n\x06\x46RAMED\x10\x01\x12\x0c\n\x08UNFRAMED\x10\x02\x12\n\n\x06HEADER\x10\x03*W\n\x0cProtocolType\x12\x11\n\rAUTO_PROTOCOL\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x0e\n\nLAX_BINARY\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x12\x0b\n\x07TWITTER\x10\x04\x42\\\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\x10ThriftProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_TRANSPORTTYPE = _descriptor.EnumDescriptor(
  name='TransportType',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.TransportType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_TRANSPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRAMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNFRAMED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1290,
  serialized_end=1363,
)
_sym_db.RegisterEnumDescriptor(_TRANSPORTTYPE)

TransportType = enum_type_wrapper.EnumTypeWrapper(_TRANSPORTTYPE)
_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_PROTOCOL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAX_BINARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPACT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TWITTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1365,
  serialized_end=1452,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOLTYPE)

ProtocolType = enum_type_wrapper.EnumTypeWrapper(_PROTOCOLTYPE)
AUTO_TRANSPORT = 0
FRAMED = 1
UNFRAMED = 2
HEADER = 3
AUTO_PROTOCOL = 0
BINARY = 1
LAX_BINARY = 2
COMPACT = 3
TWITTER = 4



_THRIFTPROXY = _descriptor.Descriptor(
  name='ThriftProxy',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.transport', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.protocol', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.stat_prefix', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.route_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thrift_filters', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.thrift_filters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_passthrough', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.payload_passthrough', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=810,
)


_THRIFTFILTER = _descriptor.Descriptor(
  name='ThriftFilter',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=813,
  serialized_end=996,
)


_THRIFTPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='ThriftProtocolOptions',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions.transport', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions.protocol', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1288,
)

_THRIFTPROXY.fields_by_name['transport'].enum_type = _TRANSPORTTYPE
_THRIFTPROXY.fields_by_name['protocol'].enum_type = _PROTOCOLTYPE
_THRIFTPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2._ROUTECONFIGURATION
_THRIFTPROXY.fields_by_name['thrift_filters'].message_type = _THRIFTFILTER
_THRIFTFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_THRIFTFILTER.oneofs_by_name['config_type'].fields.append(
  _THRIFTFILTER.fields_by_name['typed_config'])
_THRIFTFILTER.fields_by_name['typed_config'].containing_oneof = _THRIFTFILTER.oneofs_by_name['config_type']
_THRIFTPROTOCOLOPTIONS.fields_by_name['transport'].enum_type = _TRANSPORTTYPE
_THRIFTPROTOCOLOPTIONS.fields_by_name['protocol'].enum_type = _PROTOCOLTYPE
DESCRIPTOR.message_types_by_name['ThriftProxy'] = _THRIFTPROXY
DESCRIPTOR.message_types_by_name['ThriftFilter'] = _THRIFTFILTER
DESCRIPTOR.message_types_by_name['ThriftProtocolOptions'] = _THRIFTPROTOCOLOPTIONS
DESCRIPTOR.enum_types_by_name['TransportType'] = _TRANSPORTTYPE
DESCRIPTOR.enum_types_by_name['ProtocolType'] = _PROTOCOLTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ThriftProxy = _reflection.GeneratedProtocolMessageType('ThriftProxy', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTPROXY,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy)
  })
_sym_db.RegisterMessage(ThriftProxy)

ThriftFilter = _reflection.GeneratedProtocolMessageType('ThriftFilter', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTFILTER,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter)
  })
_sym_db.RegisterMessage(ThriftFilter)

ThriftProtocolOptions = _reflection.GeneratedProtocolMessageType('ThriftProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTPROTOCOLOPTIONS,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions)
  })
_sym_db.RegisterMessage(ThriftProtocolOptions)


DESCRIPTOR._options = None
_THRIFTPROXY.fields_by_name['transport']._options = None
_THRIFTPROXY.fields_by_name['protocol']._options = None
_THRIFTPROXY.fields_by_name['stat_prefix']._options = None
_THRIFTPROXY._options = None
_THRIFTFILTER.fields_by_name['name']._options = None
_THRIFTFILTER._options = None
_THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._options = None
_THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._options = None
_THRIFTPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/annotations/deprecation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/annotations/deprecation.proto',
  package='envoy.annotations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/annotations/deprecation.proto\x12\x11\x65nvoy.annotations\x1a google/protobuf/descriptor.proto:?\n\x15\x64isallowed_by_default\x12\x1d.google.protobuf.FieldOptions\x18\xe7\xad\xaeZ \x01(\x08:H\n\x1a\x64isallowed_by_default_enum\x12!.google.protobuf.EnumValueOptions\x18\xf5\xce\xb6! \x01(\x08\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


DISALLOWED_BY_DEFAULT_FIELD_NUMBER = 189503207
disallowed_by_default = _descriptor.FieldDescriptor(
  name='disallowed_by_default', full_name='envoy.annotations.disallowed_by_default', index=0,
  number=189503207, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DISALLOWED_BY_DEFAULT_ENUM_FIELD_NUMBER = 70100853
disallowed_by_default_enum = _descriptor.FieldDescriptor(
  name='disallowed_by_default_enum', full_name='envoy.annotations.disallowed_by_default_enum', index=1,
  number=70100853, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.extensions_by_name['disallowed_by_default'] = disallowed_by_default
DESCRIPTOR.extensions_by_name['disallowed_by_default_enum'] = disallowed_by_default_enum
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(disallowed_by_default)
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(disallowed_by_default_enum)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/tracing/v2/custom_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.metadata.v2 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/tracing/v2/custom_tag.proto',
  package='envoy.type.tracing.v2',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.type.tracing.v2B\016CustomTagProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/type/tracing/v2/custom_tag.proto\x12\x15\x65nvoy.type.tracing.v2\x1a%envoy/type/metadata/v2/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe3\x04\n\tCustomTag\x12\x14\n\x03tag\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12;\n\x07literal\x18\x02 \x01(\x0b\x32(.envoy.type.tracing.v2.CustomTag.LiteralH\x00\x12\x43\n\x0b\x65nvironment\x18\x03 \x01(\x0b\x32,.envoy.type.tracing.v2.CustomTag.EnvironmentH\x00\x12\x41\n\x0erequest_header\x18\x04 \x01(\x0b\x32\'.envoy.type.tracing.v2.CustomTag.HeaderH\x00\x12=\n\x08metadata\x18\x05 \x01(\x0b\x32).envoy.type.tracing.v2.CustomTag.MetadataH\x00\x1a!\n\x07Literal\x12\x16\n\x05value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a;\n\x0b\x45nvironment\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a<\n\x06Header\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a\x90\x01\n\x08Metadata\x12\x32\n\x04kind\x18\x01 \x01(\x0b\x32$.envoy.type.metadata.v2.MetadataKind\x12\x39\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v2.MetadataKey\x12\x15\n\rdefault_value\x18\x03 \x01(\tB\x0b\n\x04type\x12\x03\xf8\x42\x01\x42?\n#io.envoyproxy.envoy.type.tracing.v2B\x0e\x43ustomTagProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CUSTOMTAG_LITERAL = _descriptor.Descriptor(
  name='Literal',
  full_name='envoy.type.tracing.v2.CustomTag.Literal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.type.tracing.v2.CustomTag.Literal.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=489,
)

_CUSTOMTAG_ENVIRONMENT = _descriptor.Descriptor(
  name='Environment',
  full_name='envoy.type.tracing.v2.CustomTag.Environment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.type.tracing.v2.CustomTag.Environment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Environment.default_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=550,
)

_CUSTOMTAG_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='envoy.type.tracing.v2.CustomTag.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.type.tracing.v2.CustomTag.Header.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010 \001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Header.default_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=612,
)

_CUSTOMTAG_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='envoy.type.tracing.v2.CustomTag.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='envoy.type.tracing.v2.CustomTag.Metadata.kind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_key', full_name='envoy.type.tracing.v2.CustomTag.Metadata.metadata_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Metadata.default_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=759,
)

_CUSTOMTAG = _descriptor.Descriptor(
  name='CustomTag',
  full_name='envoy.type.tracing.v2.CustomTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='envoy.type.tracing.v2.CustomTag.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literal', full_name='envoy.type.tracing.v2.CustomTag.literal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='envoy.type.tracing.v2.CustomTag.environment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_header', full_name='envoy.type.tracing.v2.CustomTag.request_header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.type.tracing.v2.CustomTag.metadata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMTAG_LITERAL, _CUSTOMTAG_ENVIRONMENT, _CUSTOMTAG_HEADER, _CUSTOMTAG_METADATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.type.tracing.v2.CustomTag.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=161,
  serialized_end=772,
)

_CUSTOMTAG_LITERAL.containing_type = _CUSTOMTAG
_CUSTOMTAG_ENVIRONMENT.containing_type = _CUSTOMTAG
_CUSTOMTAG_HEADER.containing_type = _CUSTOMTAG
_CUSTOMTAG_METADATA.fields_by_name['kind'].message_type = envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2._METADATAKIND
_CUSTOMTAG_METADATA.fields_by_name['metadata_key'].message_type = envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2._METADATAKEY
_CUSTOMTAG_METADATA.containing_type = _CUSTOMTAG
_CUSTOMTAG.fields_by_name['literal'].message_type = _CUSTOMTAG_LITERAL
_CUSTOMTAG.fields_by_name['environment'].message_type = _CUSTOMTAG_ENVIRONMENT
_CUSTOMTAG.fields_by_name['request_header'].message_type = _CUSTOMTAG_HEADER
_CUSTOMTAG.fields_by_name['metadata'].message_type = _CUSTOMTAG_METADATA
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['literal'])
_CUSTOMTAG.fields_by_name['literal'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['environment'])
_CUSTOMTAG.fields_by_name['environment'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['request_header'])
_CUSTOMTAG.fields_by_name['request_header'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['metadata'])
_CUSTOMTAG.fields_by_name['metadata'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['CustomTag'] = _CUSTOMTAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomTag = _reflection.GeneratedProtocolMessageType('CustomTag', (_message.Message,), {

  'Literal' : _reflection.GeneratedProtocolMessageType('Literal', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_LITERAL,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Literal)
    })
  ,

  'Environment' : _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_ENVIRONMENT,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Environment)
    })
  ,

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_HEADER,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Header)
    })
  ,

  'Metadata' : _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_METADATA,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Metadata)
    })
  ,
  'DESCRIPTOR' : _CUSTOMTAG,
  '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag)
  })
_sym_db.RegisterMessage(CustomTag)
_sym_db.RegisterMessage(CustomTag.Literal)
_sym_db.RegisterMessage(CustomTag.Environment)
_sym_db.RegisterMessage(CustomTag.Header)
_sym_db.RegisterMessage(CustomTag.Metadata)


DESCRIPTOR._options = None
_CUSTOMTAG_LITERAL.fields_by_name['value']._options = None
_CUSTOMTAG_ENVIRONMENT.fields_by_name['name']._options = None
_CUSTOMTAG_HEADER.fields_by_name['name']._options = None
_CUSTOMTAG.oneofs_by_name['type']._options = None
_CUSTOMTAG.fields_by_name['tag']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/trace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.trace.v3 import datadog_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2
from envoy.config.trace.v3 import dynamic_ot_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2
from envoy.config.trace.v3 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2
from envoy.config.trace.v3 import lightstep_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2
from envoy.config.trace.v3 import opencensus_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2
from envoy.config.trace.v3 import service_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_service__pb2
from envoy.config.trace.v3 import zipkin_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2

from envoy.config.trace.v3.datadog_pb2 import *
from envoy.config.trace.v3.dynamic_ot_pb2 import *
from envoy.config.trace.v3.http_tracer_pb2 import *
from envoy.config.trace.v3.lightstep_pb2 import *
from envoy.config.trace.v3.opencensus_pb2 import *
from envoy.config.trace.v3.service_pb2 import *
from envoy.config.trace.v3.zipkin_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v3/trace.proto',
  package='envoy.config.trace.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v3B\nTraceProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/config/trace/v3/trace.proto\x12\x15\x65nvoy.config.trace.v3\x1a#envoy/config/trace/v3/datadog.proto\x1a&envoy/config/trace/v3/dynamic_ot.proto\x1a\'envoy/config/trace/v3/http_tracer.proto\x1a%envoy/config/trace/v3/lightstep.proto\x1a&envoy/config/trace/v3/opencensus.proto\x1a#envoy/config/trace/v3/service.proto\x1a\"envoy/config/trace/v3/zipkin.protoB3\n#io.envoyproxy.envoy.config.trace.v3B\nTraceProtoP\x01P\x00P\x01P\x02P\x03P\x04P\x05P\x06\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_service__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_service__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cache/v3alpha/cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/cache/v3alpha/cache.proto',
  package='envoy.extensions.filters.http.cache.v3alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.extensions.filters.http.cache.v3alphaB\nCacheProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/extensions/filters/http/cache/v3alpha/cache.proto\x12+envoy.extensions.filters.http.cache.v3alpha\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf2\x04\n\x0b\x43\x61\x63heConfig\x12\x34\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01\x12\x42\n\x14\x61llowed_vary_headers\x18\x02 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x65\n\x12key_creator_params\x18\x03 \x01(\x0b\x32I.envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams\x12\x16\n\x0emax_body_bytes\x18\x04 \x01(\r\x1a\xae\x02\n\x10KeyCreatorParams\x12\x16\n\x0e\x65xclude_scheme\x18\x01 \x01(\x08\x12\x14\n\x0c\x65xclude_host\x18\x02 \x01(\x08\x12O\n\x19query_parameters_included\x18\x03 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher\x12O\n\x19query_parameters_excluded\x18\x04 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.cache.v2alpha.CacheConfigBY\n9io.envoyproxy.envoy.extensions.filters.http.cache.v3alphaB\nCacheProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CACHECONFIG_KEYCREATORPARAMS = _descriptor.Descriptor(
  name='KeyCreatorParams',
  full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exclude_scheme', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.exclude_scheme', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_host', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.exclude_host', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameters_included', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.query_parameters_included', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameters_excluded', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.query_parameters_excluded', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036E\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=872,
)

_CACHECONFIG = _descriptor.Descriptor(
  name='CacheConfig',
  full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.typed_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\242\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_vary_headers', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.allowed_vary_headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_creator_params', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.key_creator_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_body_bytes', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.max_body_bytes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CACHECONFIG_KEYCREATORPARAMS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.filter.http.cache.v2alpha.CacheConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=931,
)

_CACHECONFIG_KEYCREATORPARAMS.fields_by_name['query_parameters_included'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._QUERYPARAMETERMATCHER
_CACHECONFIG_KEYCREATORPARAMS.fields_by_name['query_parameters_excluded'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._QUERYPARAMETERMATCHER
_CACHECONFIG_KEYCREATORPARAMS.containing_type = _CACHECONFIG
_CACHECONFIG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CACHECONFIG.fields_by_name['allowed_vary_headers'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_CACHECONFIG.fields_by_name['key_creator_params'].message_type = _CACHECONFIG_KEYCREATORPARAMS
DESCRIPTOR.message_types_by_name['CacheConfig'] = _CACHECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CacheConfig = _reflection.GeneratedProtocolMessageType('CacheConfig', (_message.Message,), {

  'KeyCreatorParams' : _reflection.GeneratedProtocolMessageType('KeyCreatorParams', (_message.Message,), {
    'DESCRIPTOR' : _CACHECONFIG_KEYCREATORPARAMS,
    '__module__' : 'envoy.extensions.filters.http.cache.v3alpha.cache_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams)
    })
  ,
  'DESCRIPTOR' : _CACHECONFIG,
  '__module__' : 'envoy.extensions.filters.http.cache.v3alpha.cache_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cache.v3alpha.CacheConfig)
  })
_sym_db.RegisterMessage(CacheConfig)
_sym_db.RegisterMessage(CacheConfig.KeyCreatorParams)


DESCRIPTOR._options = None
_CACHECONFIG_KEYCREATORPARAMS._options = None
_CACHECONFIG.fields_by_name['typed_config']._options = None
_CACHECONFIG._options = None
# @@protoc_insertion_point(module_scope)
